@@ -131,8 +131,8 @@ void MainWindow::positionUpdated(const QGeoPositionInfo &info)
         }
     }
     else {
-        QMessageBox::information(this, tr("Error"),
-                tr("Invalid GPS details."),
+        QMessageBox::information(this, tr("GPS Error"),
+                tr("Invalid GPS details. Possible cause weak GPS signal."),
                 QMessageBox::Ok);
     }
 }
@@ -156,6 +156,8 @@ void MainWindow::on_m_info_toggled(bool checked)
     }
     else
         webView->page()->mainFrame()->evaluateJavaScript("closeInfoWindow()");
+
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 }
 
 void MainWindow::updateGoogleMap(QString pLat, QString pLng)
@@ -190,6 +192,7 @@ void MainWindow::on_m_spotme_toggled(bool checked)
         enable();
         qDebug() << "GPS enabled";
     } else {
+        on_m_info_toggled(false);
         m_info->setChecked(false);
         disable();
         qDebug() << "GPS disabled";
